@@ -9,7 +9,7 @@ def test_missing_options1(live_server, selenium):
     required options have not been specified.
     """
     # Load webpage for test
-    params = {'template_name': 'initialization/missing_options1.html'}
+    params = {'template_name': 'initialization/missing_options_1.html'}
     test_url = f'{live_server.url}?{urlencode(params)}'
     selenium.get(test_url)
 
@@ -31,7 +31,7 @@ def test_missing_options2(live_server, selenium):
     options that are conditionally required have not been specified.
     """
     # Load webpage for test
-    params = {'template_name': 'initialization/missing_options2.html'}
+    params = {'template_name': 'initialization/missing_options_2.html'}
     test_url = f'{live_server.url}?{urlencode(params)}'
     selenium.get(test_url)
 
@@ -44,7 +44,8 @@ def test_missing_options2(live_server, selenium):
         '[ConvenientFormset] Missing required options: '
         '`formsetPrefix`, `formsContainerSelector`, `formSelector`, '
         '`addFormButtonSelector`, `emptyFormSelector`, '
-        '`deleteFormButtonSelector`'
+        '`deleteFormButtonSelector`, `moveFormDownButtonSelector`, '
+        '`moveFormUpButtonSelector`'
     ]
 
 
@@ -54,7 +55,7 @@ def test_missing_formset_elements1(live_server, selenium):
     required formset elements are missing.
     """
     # Load webpage for test
-    params = {'template_name': 'initialization/missing_formset_elements1.html'}
+    params = {'template_name': 'initialization/missing_formset_elements_1.html'}
     test_url = f'{live_server.url}?{urlencode(params)}'
     selenium.get(test_url)
 
@@ -73,10 +74,11 @@ def test_missing_formset_elements1(live_server, selenium):
 def test_missing_formset_elements2(live_server, selenium):
     """
     Asserts the ConvenientFormset instantiation raises an error message when
-    the `deleteFormButtonSelector` cannot be found in the empty form.
+    the `deleteFormButtonSelector`, the `moveFormDownButtonSelector` and the
+    `moveFormUpButtonSelector` cannot be found in the empty form.
     """
     # Load webpage for test
-    params = {'template_name': 'initialization/missing_formset_elements2.html'}
+    params = {'template_name': 'initialization/missing_formset_elements_2.html'}
     test_url = f'{live_server.url}?{urlencode(params)}'
     selenium.get(test_url)
 
@@ -87,17 +89,19 @@ def test_missing_formset_elements2(live_server, selenium):
     ]
     assert error_messages == [
         '[ConvenientFormset] Unable to find DOM elements in empty form with '
-        'selectors: `#delete-form-button`'
+        'selectors: `#delete-form-button`, `#move-form-down-button`, '
+        '`#move-form-up-button`, `input[name$="ORDER"]`'
     ]
 
 
 def test_missing_formset_elements3(live_server, selenium):
     """
     Asserts the ConvenientFormset instantiation raises an error message when
-    the `deleteFormButtonSelector` cannot be found in visible forms.
+    the `deleteFormButtonSelector`, the `moveFormDownButtonSelector` and the
+    `moveFormUpButtonSelector` cannot be found in visible forms.
     """
     # Load webpage for test
-    params = {'template_name': 'initialization/missing_formset_elements3.html'}
+    params = {'template_name': 'initialization/missing_formset_elements_3.html'}
     test_url = f'{live_server.url}?{urlencode(params)}'
     selenium.get(test_url)
 
@@ -108,7 +112,8 @@ def test_missing_formset_elements3(live_server, selenium):
     ]
     assert error_messages == [
         '[ConvenientFormset] Unable to find DOM elements in one or more '
-        'visible forms with selectors: `#delete-form-button`'
+        'visible forms with selectors: `#delete-form-button`, '
+        '`#move-form-down-button`, `#move-form-up-button`, `input[name$="ORDER"]`'
     ]
 
 
@@ -133,7 +138,7 @@ def test_missing_management_form(live_server, selenium):
     ]
 
 
-def test_hiding_forms_marked_for_deletion1(live_server, selenium):
+def test_hiding_forms_marked_for_deletion1(live_server, selenium, is_legacy_edge):
     """
     ConvenientFormset has the `deleteFormButtonSelector` option set, hiding
     forms marked for deletion to be hidden when initializing.
@@ -154,11 +159,16 @@ def test_hiding_forms_marked_for_deletion1(live_server, selenium):
     forms = selenium.find_elements(
             By.CSS_SELECTOR, '#formset #forms-container .form')
     assert len(forms) == 2
-    assert forms[0].get_attribute('hidden') is not None
-    assert forms[1].get_attribute('hidden') is None
+
+    if is_legacy_edge(getattr(selenium, 'desired_capabilities', {})):
+        assert forms[0].get_attribute('hidden') == 'true'
+        assert forms[1].get_attribute('hidden') == 'false'
+    else:
+        assert forms[0].get_attribute('hidden') is not None
+        assert forms[1].get_attribute('hidden') is None
 
 
-def test_hiding_forms_marked_for_deletion2(live_server, selenium):
+def test_hiding_forms_marked_for_deletion2(live_server, selenium, is_legacy_edge):
     """
     ConvenientFormset has the `deleteFormButtonSelector` option *NOT* set,
     leaving forms marked for deletion alone when initializing.
@@ -179,11 +189,16 @@ def test_hiding_forms_marked_for_deletion2(live_server, selenium):
     forms = selenium.find_elements(
             By.CSS_SELECTOR, '#formset #forms-container .form')
     assert len(forms) == 2
-    assert forms[0].get_attribute('hidden') is None
-    assert forms[1].get_attribute('hidden') is None
+
+    if is_legacy_edge(getattr(selenium, 'desired_capabilities', {})):
+        assert forms[0].get_attribute('hidden') == 'false'
+        assert forms[1].get_attribute('hidden') == 'false'
+    else:
+        assert forms[0].get_attribute('hidden') is None
+        assert forms[1].get_attribute('hidden') is None
 
 
-def test_hiding_add_form_button_on_max_forms1(live_server, selenium):
+def test_hiding_add_form_button_on_max_forms1(live_server, selenium, is_legacy_edge):
     """
     ConvenientFormset has the `hideAddFormButtonOnMaxForms` option set to
     `true`, hiding the add form button when initializing.
@@ -203,10 +218,13 @@ def test_hiding_add_form_button_on_max_forms1(live_server, selenium):
     # Assert add form button does have the `hidden` attribute set
     add_form_button = selenium.find_element(
             By.CSS_SELECTOR, '#formset #add-form-button')
-    assert add_form_button.get_attribute('hidden') is not None
+    if is_legacy_edge(getattr(selenium, 'desired_capabilities', {})):
+        assert add_form_button.get_attribute('hidden') == 'true'
+    else:
+        assert add_form_button.get_attribute('hidden') is not None
 
 
-def test_hiding_add_form_button_on_max_forms2(live_server, selenium):
+def test_hiding_add_form_button_on_max_forms2(live_server, selenium, is_legacy_edge):
     """
     ConvenientFormset has the `hideAddFormButtonOnMaxForms` option set to
     `false`, leaving the add form button alone when initializing.
@@ -226,4 +244,7 @@ def test_hiding_add_form_button_on_max_forms2(live_server, selenium):
     # Assert add form button does NOT have the `hidden` attribute set
     add_form_button = selenium.find_element(
             By.CSS_SELECTOR, '#formset #add-form-button')
-    assert add_form_button.get_attribute('hidden') is None
+    if is_legacy_edge(getattr(selenium, 'desired_capabilities', {})):
+        assert add_form_button.get_attribute('hidden') == 'false'
+    else:
+        assert add_form_button.get_attribute('hidden') is None
